"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.distance = distance;
exports.getBBoxByArray = getBBoxByArray;
exports.getBBoxRange = getBBoxRange;
exports.isNumberEqual = isNumberEqual;
exports.piMod = piMod;

var _tslib = require("tslib");

/**
 * 两点之间的距离
 * @param {number} x1 起始点 x
 * @param {number} y1 起始点 y
 * @param {number} x2 结束点 x
 * @param {number} y2 结束点 y
 * @return {number} 距离
 */
function distance(x1, y1, x2, y2) {
  var dx = x1 - x2;
  var dy = y1 - y2;
  return Math.sqrt(dx * dx + dy * dy);
}

function isNumberEqual(v1, v2) {
  return Math.abs(v1 - v2) < 0.001;
}

function getBBoxByArray(xArr, yArr) {
  var minX = Math.min.apply(Math, (0, _tslib.__spreadArray)([], (0, _tslib.__read)(xArr), false));
  var minY = Math.min.apply(Math, (0, _tslib.__spreadArray)([], (0, _tslib.__read)(yArr), false));
  var maxX = Math.max.apply(Math, (0, _tslib.__spreadArray)([], (0, _tslib.__read)(xArr), false));
  var maxY = Math.max.apply(Math, (0, _tslib.__spreadArray)([], (0, _tslib.__read)(yArr), false));
  return {
    x: minX,
    y: minY,
    width: maxX - minX,
    height: maxY - minY
  };
}

function getBBoxRange(x1, y1, x2, y2) {
  return {
    minX: Math.min(x1, x2),
    maxX: Math.max(x1, x2),
    minY: Math.min(y1, y2),
    maxY: Math.max(y1, y2)
  };
}

function piMod(angle) {
  return (angle + Math.PI * 2) % (Math.PI * 2);
}